==> tuia-advert-center-api-2.4.44-sources.jar: cn/com/duiba/tuia/core/api/dto/media/request/MediaAlreadSlotWhiteReq.java <==
package cn.com.duiba.tuia.core.api.dto.media.request;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;
import java.util.List;

/**
 * @author zhangmeng
 * @date 2019/6/26
 * @function
 */
public class MediaAlreadSlotWhiteReq implements Serializable {


    private static final long serialVersionUID = -8652858850978628304L;

    /**
     * 广告位id
     */
    private Long slotId;

    /**
     * 广告ids
     */
    private List<Long> advertIds;

    /**
     * 广告名称
     */
    private String advertName;

    /**
     * 广告主名称
     */
    private String accountName;

    /**
     * 广告主列表
     */
    private List<Long> accountIds;

    /** 审核状态. */
    private Integer checkStatus;
    /** 有效状态. */
    private Integer validStatus;
    /** 启用状态. */
    private Integer enableStatus;

    /**
     * 每页大小
     */
    private Integer pageSize;

    /**
     * 第几页
     */
    private Integer pageCount;

    public List<Long> getAdvertIds() {
        return advertIds;
    }

    public void setAdvertIds(List<Long> advertIds) {
        this.advertIds = advertIds;
    }

    public String getAdvertName() {
        return advertName;
    }

    public void setAdvertName(String advertName) {
        this.advertName = advertName;
    }

    public String getAccountName() {
        return accountName;
    }

    public void setAccountName(String accountName) {
        this.accountName = accountName;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public Integer getPageCount() {
        return pageCount;
    }

    public void setPageCount(Integer pageCount) {
        this.pageCount = pageCount;
    }

    public List<Long> getAccountIds() {
        return accountIds;
    }

    public void setAccountIds(List<Long> accountIds) {
        this.accountIds = accountIds;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Integer getCheckStatus() {
        return checkStatus;
    }

    public void setCheckStatus(Integer checkStatus) {
        this.checkStatus = checkStatus;
    }

    public Integer getValidStatus() {
        return validStatus;
    }

    public void setValidStatus(Integer validStatus) {
        this.validStatus = validStatus;
    }

    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}

==> tuia-advert-center-api-2.5.21-sources.jar: cn/com/duiba/tuia/core/api/dto/media/request/MediaAlreadSlotWhiteReq.java <==
package cn.com.duiba.tuia.core.api.dto.media.request;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;
import java.util.List;

/**
 * @author zhangmeng
 * @date 2019/6/26
 * @function
 */
public class MediaAlreadSlotWhiteReq implements Serializable {


    private static final long serialVersionUID = -8652858850978628304L;

    /**
     * 广告位id
     */
    private Long slotId;

    /**
     * 广告ids
     */
    private List<Long> advertIds;

    /**
     * 广告名称
     */
    private String advertName;

    /**
     * 广告主名称
     */
    private String accountName;

    /**
     * 广告主列表
     */
    private List<Long> accountIds;

    /** 审核状态. */
    private Integer checkStatus;
    /** 有效状态. */
    private Integer validStatus;
    /** 启用状态. */
    private Integer enableStatus;

    /** 行业标签（模糊查询）*/
    private String industryTag;

    /** 资源标签（模糊查询）*/
    private String resourceTag;

    /** 落地页标签（模糊查询）*/
    private String promoteTag;

    /** 广告状态：0-无效；1-有效 */
    private Integer advertState;

    /**
     * 每页大小
     */
    private Integer pageSize;

    /**
     * 第几页
     */
    private Integer pageCount;

    public List<Long> getAdvertIds() {
        return advertIds;
    }

    public void setAdvertIds(List<Long> advertIds) {
        this.advertIds = advertIds;
    }

    public String getAdvertName() {
        return advertName;
    }

    public void setAdvertName(String advertName) {
        this.advertName = advertName;
    }

    public String getAccountName() {
        return accountName;
    }

    public void setAccountName(String accountName) {
        this.accountName = accountName;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public Integer getPageCount() {
        return pageCount;
    }

    public void setPageCount(Integer pageCount) {
        this.pageCount = pageCount;
    }

    public List<Long> getAccountIds() {
        return accountIds;
    }

    public void setAccountIds(List<Long> accountIds) {
        this.accountIds = accountIds;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Integer getCheckStatus() {
        return checkStatus;
    }

    public void setCheckStatus(Integer checkStatus) {
        this.checkStatus = checkStatus;
    }

    public Integer getValidStatus() {
        return validStatus;
    }

    public void setValidStatus(Integer validStatus) {
        this.validStatus = validStatus;
    }

    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }

    public String getIndustryTag() {
        return industryTag;
    }

    public void setIndustryTag(String industryTag) {
        this.industryTag = industryTag;
    }

    public String getResourceTag() {
        return resourceTag;
    }

    public void setResourceTag(String resourceTag) {
        this.resourceTag = resourceTag;
    }

    public String getPromoteTag() {
        return promoteTag;
    }

    public void setPromoteTag(String promoteTag) {
        this.promoteTag = promoteTag;
    }

    public Integer getAdvertState() {
        return advertState;
    }

    public void setAdvertState(Integer advertState) {
        this.advertState = advertState;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}
